%{
Script for setting up the wake vortex system for J = 0.60
( positive thrst condition) for the wake-informed lifting line code.

Copyright 2025 Jatinder Goyal

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
%}
%%
slipstream.rRTip = [1,1,1]; % Tip radial stations (assuming no contraction)
slipstream.rRRoot = rR_root*[1, 1, 1]; % Root radial stations

% Calculate the axial position of the vortex elements at the tip and root
slipstream.xRTip = [0, polyFitWake1(slipstream.rRTip(2)), polyFitWake2(slipstream.rRTip(3))];
slipstream.xRRoot = [0, polyFitWake1(slipstream.rRRoot(2)), polyFitWake2(slipstream.rRRoot(3))];
%% vortex system
ll.d1firstWakeX = 0;
ll.d1firstWakeY = 0;
ll.d1firstWakeZ = [slipstream.rRRoot(1) slipstream.rRTip(1)]*D/2;

ll.Lwake = 5; % [-] Length of the wake normalized with radius
ll.dtheta = 2;  % [deg] Angular resolution of the wake

ll.dt_plane = 1/(n*B); % time between the blade wakes
ll.th_plane = 360/B; % Angular spacing between propeller blades
ll.dt = ll.dt_plane/ll.th_plane*ll.dtheta; % Time step of vortex elements

% Calculate the slipstream velocity at the tip
ll.VslipTip = diff(slipstream.xRTip*(D/2))/ll.dt_plane;

% Determine the number of wake points and time steps
ll.WakePoints = [repmat(ll.th_plane/ll.dtheta,1,length(slipstream.xRTip)-1), round((ll.Lwake - slipstream.xRTip(end))*(D/2)./(ll.VslipTip(end)*ll.dt))]+1;
ll.d1time = ll.dt*(0:1:sum(ll.WakePoints)-1);

%% Define additional radial stations and calculate vortex positions
ll.rR = [slipstream.rRRoot(1), rR_input, slipstream.rRTip(1)];
ll.rRStation_xRVort = [zeros(length(ll.rR),1), polyFitWake1(ll.rR),polyFitWake2(ll.rR)]; % axial location of vortices along the given radial stations
ll.Vvort = diff(ll.rRStation_xRVort'*(D/2))'/ll.dt_plane;

ll.d2x_vortex_rR = zeros(length(ll.rR),length(ll.d1time));
ll.Vvort(:,end+1) = ll.Vvort(:,end);

% Compute vortex positions based on blade wake and time information available
for iwake = 1:length(ll.WakePoints)
    if iwake==1
        ll.d2x_vortex_rR(:,1:ll.WakePoints(iwake)) = ll.Vvort(:,iwake)*ll.d1time(1:ll.WakePoints(iwake));
    else
        ll.d2x_vortex_rR(:,sum(ll.WakePoints(1:iwake-1))+1:sum(ll.WakePoints(1:iwake))) =  ll.d2x_vortex_rR(:,sum(ll.WakePoints(1:iwake-1))) + ll.Vvort(:,iwake)*(ll.d1time(sum(ll.WakePoints(1:iwake-1))+1:sum(ll.WakePoints(1:iwake))) - ll.d1time(sum(ll.WakePoints(1:iwake-1))));
    end
end

ll.d2z_vortex_rR = ll.rR'.*sin(n*2*pi*ll.d1time)*(D/2);
ll.d2y_vortex_rR = ll.rR'.*cos(n*2*pi*ll.d1time)*(D/2);


% Rotate the vortex positions for lifting line elements from other blades
[ll.b2.d2y_vortex_rR, ll.b2.d2z_vortex_rR]= rotate(ll.d2y_vortex_rR,ll.d2z_vortex_rR,120);
[ll.b3.d2y_vortex_rR, ll.b3.d2z_vortex_rR]= rotate(ll.d2y_vortex_rR,ll.d2z_vortex_rR,240);

%%