%{
Script for solving the wake-informed lifting line system for
the given control poitns and input data.

Copyright 2025 Jatinder Goyal

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
%}
%%
cnvg.cutoff = 0.01; % vortex core for Biot-Savart law
for i = 1:B
    [ytmp, ztmp]= rotate(ll.d2y_vortex_rR,ll.d2z_vortex_rR,(i-1)*360/B); %rotate input in meters (not normalized)
    [ytmp_bound, ztmp_bound] = rotate(ll.rR*D/2,zeros(1,length(ll.rR)),(i-1)*360/B);

    for ridx = 1:length(ll.d2x_vortex_rR(:,1))

        [d3aU(:,:,i),d3aV(:,:,i),d3aW(:,:,i)] = biotSavart(controlPoint.xR*D/2,controlPoint.rR*D/2,controlPoint.zR*D/2,...
            ll.d2x_vortex_rR(ridx,:),ytmp(ridx,:),ztmp(ridx,:),cnvg.cutoff);

        d3aU_rR(:,:,i,ridx) = d3aU(:,:,i);
        d3aV_rR(:,:,i,ridx) = d3aV(:,:,i);
        d3aW_rR(:,:,i,ridx) = d3aW(:,:,i);
        clear d3aU d3aV d3aW
    end
    clear ytmp ztmp

    [d3aU_bound(:,:,i),d3aV_bound(:,:,i),d3aW_bound(:,:,i)] = biotSavart(controlPoint.xR*D/2,controlPoint.rR*D/2,controlPoint.zR*D/2,...
        zeros(1,length(ll.rR)),ytmp_bound,ztmp_bound,cnvg.cutoff);

    clear ytmp_bound ztmp_bound
end

% Sum induced velocities over all blades and vortices
controlPoint.UindCoeff = squeeze(sum(sum(d3aU_rR,3),2));
controlPoint.VindCoeff = squeeze(sum(sum(d3aV_rR,3),2));
controlPoint.WindCoeff = squeeze(sum(sum(d3aW_rR,3),2));

controlPoint.UindCoeff_bound = squeeze(sum(d3aU_bound,3));
controlPoint.VindCoeff_bound = squeeze(sum(d3aV_bound,3));
controlPoint.WindCoeff_bound = squeeze(sum(d3aW_bound,3));

clear d3aU_rR d3aV_rR d3aW_rR d3aU_bound d3aV_bound d3aW_bound
%% Optimization to Find Gamma Bound
% Initial guess for Gamma Bound
if np == 1
    GammaBound0 = ones(length(ll.rR)-1,1);
else
    GammaBound0 = mean(WIL.GammaBound(:,1:np-1),2);
end

% Optimization options
options = optimoptions('lsqnonlin','FiniteDifferenceType','central', ...
    'FunctionTolerance',1e-16,'Diagnostics','off','Display','iter', ...
    'MaxIterations',1000,'StepTolerance',1e-16,'OptimalityTolerance',1e-16, ...
    'MaxFunctionEvaluations', 1e5);

% Solve for Gamma Bound using non-linear least squares
GammaBoundSol = lsqnonlin(@(gammaBound) error_velocity(gammaBound,controlPoint,SlipstreamData), GammaBound0,[],[],options);

% Calculate error and induced velocities using the solution
[CPerror, GammaWakeSol, UInd, VInd, WInd] = error_velocity(GammaBoundSol,controlPoint,SlipstreamData);
