%{
Calcualte induced velocities for each vortex line using Biot Savart's law

Copyright 2025 Jatinder Goyal

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
%}
%%
function [d2velU,d2velV,d2velW] = biotSavartBound(xCP,yCP,zCP,d1x_vortex,d1y_vortex,d1z_vortex,d1cutoff)
% Calculate the induced velocities using the Biot-Savart law for a vortex line
%
% Inputs:
%   xCP, yCP, zCP     - Coordinates of the control points
%   d1x_vortex, d1y_vortex, d1z_vortex - Vortex segment coordinates
%   d1cutoff - Cutoff distance for the Biot-Savart law
%
% Outputs:
%   d2velU, d2velV, d2velW - Induced velocities in U, V, and W directions


iElem = length(d1x_vortex);

d1inflPX = d1x_vortex;
d1inflPY = d1y_vortex;
d1inflPZ = d1z_vortex;
d1Circ   = ones(1,iElem-1);

[d2velU,d2velV,d2velW] = vortexLineLambOseen(xCP',yCP',zCP',d1inflPX(2:end),d1inflPY(2:end),d1inflPZ(2:end),...
    d1inflPX(1:end-1),d1inflPY(1:end-1),d1inflPZ(1:end-1),d1Circ,d1cutoff);



