%{
Script for plotting vorticity and polynimials for the blade wake fit.

Copyright 2025 Jatinder Goyal

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
%}
%%
smoothedVortMat_norm = smoothdata(CURLZ_norm, 'gaussian', 10); % Adjust the window size as needed
%%
xRPlot = 0:0.1:6;
rRPlot = 0.23:0.01:1;

figure();
plot(fitX1,fitY1,'k')
if J == 0.60
    plot(fitX2,fitY2,'k')
end
plot([0 1.2],[1 1],'k-.','LineWidth',1)
plot(highVorticityX1,highVorticityY1,'r*','MarkerSize',1)
if J == 0.60
    plot(highVorticityX2,highVorticityY2,'r*','MarkerSize',1)
end
plotGeom_2D;
axis equal

xlabel('Axial coordinate $x/R$')
ylabel('Radial coordinate $r/R$')
xlim([-inf 1.2])
ylim([0 1.2])
xtickformat('%.01f')
ytickformat('%.01f')
xticks(0:0.3:1.2)
yticks(0:0.2:1.2)
ax = gca;
ax.Layer = 'top';
ax.FontSize = 16;
%%

clear cb
cb.cmin = -5;
cb.cmax = 5;
cb.cdelta = 1;
cskip = 0;
cb.TickValues = cb.cmin:cb.cdelta*(cskip+1):cb.cmax;
cb.ctitle = '$\langle{\vec{\omega}^*}_t\rangle_{\mathcal{G}(\vec{r})}$';

cb.nContours = round((cb.cmax-cb.cmin)/cb.cdelta);
cb.nContours = cb.nContours+1; % for centerline

cb.cmax = cb.cmax+cb.cdelta/2;
cb.cmin = cb.cmin-cb.cdelta/2;
cb.cLevels = cb.cmin:cb.cdelta:cb.cmax;
cb.cTickFormat = '%0.01f';
cb.cLevels(1) = cb.cmin-1e9;
cb.cLevels(end) = cb.cmax + 1e9;

contourf(inData.xR,inData.rR,smoothedVortMat_norm,cb.cLevels,'LineColor','none')
caxis([cb.cmin cb.cmax])
colormap(parula(11))
caxis([-5.5 5.5])
%%
fontsize = 16;
hcb = colorbar;
hcb.Ticks = cb.TickValues(1:2:end);
hcb.LineWidth = 1.0;
hcb.TickLabelInterpreter = 'latex';
hcb.FontSize = fontsize;

title(hcb,cb.ctitle,'fontsize',fontsize+1,'interpreter','latex')
%%
ax.Children = flip(ax.Children);
axis equal
ylim([0 1.2])
xlim([-inf 1.2])

%%
if curveFitPlotSave
    figName2 = [savePlotDir,sprintf('%s_curveFitPlot_J%.02f',dataSet,J)];
    saveas(gcf,[figName2,'.fig'],'fig')
    saveas(gcf,[figName2,'.png'],'png')
    saveas(gcf,[figName2,'.svg'],'svg')
    saveas(gcf,[figName2,'.pdf'],'pdf')
end