%{
Script for plotting helical wake system.

Copyright 2025 Jatinder Goyal

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
%}
%%
figure();
% Plot vortex system
plot3(ll.d2x_vortex_rR'/(D/2),ll.d2y_vortex_rR'/(D/2),ll.d2z_vortex_rR'/(D/2),'b')
plot3(ll.d2x_vortex_rR'/(D/2),ll.b3.d2y_vortex_rR'/(D/2),ll.b3.d2z_vortex_rR'/(D/2),'r')
plot3(ll.d2x_vortex_rR'/(D/2),ll.b2.d2y_vortex_rR'/(D/2),ll.b2.d2z_vortex_rR'/(D/2),'g')

plot(fitX1,fitY1,'k')
if J == 0.60
    plot(fitX2,fitY2,'k')
end
plot([slipstream.xRTip,xRPlot(end)],[slipstream.rRTip,slipstream.rRTip(end)],'-.k','LineWidth',1)

if J == 0.60
    plot([slipstream.xRTip(1)+0.2,xRPlot(end)],-[slipstream.rRTip(1),slipstream.rRTip(end)],'-.k','LineWidth',1)
else
    plot([slipstream.xRTip(1)+0.35,xRPlot(end)],-[slipstream.rRTip(1),slipstream.rRTip(end)],'-.k','LineWidth',1)
end
% plot([0 1.2],[1 1],'k-.','LineWidth',1)
plotGeom_2D;



xlabel('Axial coordinate $x/R$')
ylabel('Radial coordinate $r/R$')

xtickformat('%.0f')
ytickformat('%.01f')

ax = gca;
ax.Layer = 'top';
ax.FontSize = 10;
%%

clear cb
cb.cmin = -5;
cb.cmax = 5;
cb.cdelta = 1;
cskip = 0;
cb.TickValues = cb.cmin:cb.cdelta*(cskip+1):cb.cmax;
cb.ctitle = '${\vec{\omega}^*}_t$';

cb.nContours = round((cb.cmax-cb.cmin)/cb.cdelta);
cb.nContours = cb.nContours+1; % for centerline

cb.cmax = cb.cmax+cb.cdelta/2;
cb.cmin = cb.cmin-cb.cdelta/2;
cb.cLevels = cb.cmin:cb.cdelta:cb.cmax;
cb.cTickFormat = '%0.01f';
cb.cLevels(1) = cb.cmin-1e9;
cb.cLevels(end) = cb.cmax + 1e9;

% contourf(inData.xR,inData.rR,inData.CURLZ_norm,cb.cLevels,'LineColor','none')
surf(inData.xR,inData.rR,zeros(size(inData.xR)),inData.CURLZ_norm,'EdgeColor','none','FaceColor','interp')
caxis([cb.cmin cb.cmax])
colormap(parula(11))
caxis([-5.5 5.5])
%%
fontsize = 16;
hcb = colorbar;
hcb.Ticks = cb.TickValues(1:2:end);
hcb.LineWidth = 1.0;
hcb.TickLabelInterpreter = 'latex';
hcb.FontSize = fontsize;

title(hcb,cb.ctitle,'fontsize',fontsize+1,'interpreter','latex')
%%
ax.Children = flip(ax.Children);
% axis equal
% ylim([0 1.2])
% xlim([-inf 1.2])
% Set axis properties
axis equal
ylim([-1.2 1.2])
yticks(-1.2:0.6:1.2)
xticks(0:6)
xlim([-inf 6])
%%
if helicalSystemPlotSave
    % Save main plot
    fg = gcf;
    fg.Renderer = 'painters';
    figName2 = sprintf('%s_helix_J%.02f',dataSet,J);

    saveas(gcf,[savePlotDir,figName2,'.fig'],'fig')
    saveas(gcf,[savePlotDir,figName2,'.png'],'png')
    saveas(gcf,[savePlotDir,figName2,'.svg'],'svg')
    saveas(gcf,[savePlotDir,figName2,'.pdf'],'pdf')
end
